@@ -10,6 +10,7 @@ from SDP18py.read_MAS import read_mas1
 from SDP18py.read_csv import read_csv1
 from SDP18py.read_toschedule import read_toschedule1
 import sqlite3
+from tkinter.tix import *
 
 
 def register_page():
@@ -86,6 +87,9 @@ def login_page():
     label2.place(relx=0.35, rely=0.35)
     label2.config(font=('', 10))
 
+    tooltip1 = Balloon(frame1)
+    tooltip1.bind_widget(label2, balloonmsg='Please select the discipline of the surgery procedures to be scheduled')
+
     disc_list = ['BREAST', 'OTO', 'NES', 'CLR', 'HPB', 'PLS', 'ENT','SUR-ONCO', 'UGI', 'H&N', 'O&G', 'HND', 'OMS', 'VAS', 'CTS', 'URO']
 
     combobox1 = ttk.Combobox(frame1, values=disc_list, state='readonly')
@@ -123,6 +127,9 @@ def login_page():
     b1 = Button(frame2, text="Browse :", command=browsefunc1)
     b1.place(relx=0.75, rely=0.35)
 
+    tooltip = Balloon(frame2)
+    tooltip.bind_widget(b1, balloonmsg='Please refer to the documentation for the corresponding csv templates')
+
     label6 = Label(frame2, text='Select the to be Scheduled .csv file :')
     label6.place(relx=0.2, rely=0.42)
     label6.config(font=('', 10))
@@ -141,6 +148,7 @@ def login_page():
 
     b2 = Button(frame2, text="Browse :", command=browsefunc2)
     b2.place(relx=0.75, rely=0.45)
+    tooltip.bind_widget(b2, balloonmsg='Please refer to the documentation for the corresponding csv templates')
 
     label7 = Label(frame2, text='Select the MAS .csv file :')
     label7.place(relx=0.2, rely=0.52)
@@ -160,6 +168,7 @@ def login_page():
 
     b3 = Button(frame2, text="Browse :", command=browsefunc3)
     b3.place(relx=0.75, rely=0.55)
+    tooltip.bind_widget(b3, balloonmsg='Please refer to the documentation for the corresponding csv templates')
 
     divider_frame2 = Frame(screen2, bg='grey')
     divider_frame2.place(relx=0.665, rely=0, relwidth=0.005, relheight=1)
@@ -187,6 +196,7 @@ def login_page():
         current_schedule = read_csv1(file_path_1)
         to_schedule = read_toschedule1(file_path_2)
         mas_full = read_mas1(file_path_3)
+        disc_selected = combobox1.get()
 
         optimizer_selected = list_box.get(list_box.curselection())
 
@@ -194,13 +204,13 @@ def login_page():
                           'Genetic Algorithm': 4}
 
         if optimizer_dict[optimizer_selected] == 1:
-            run_hco(current_schedule, to_schedule, mas_full)
+            run_hco(current_schedule, to_schedule, mas_full, disc_selected)
         if optimizer_dict[optimizer_selected] == 2:
-            run_ts(current_schedule, to_schedule, mas_full)
+            run_ts(current_schedule, to_schedule, mas_full, disc_selected)
         if optimizer_dict[optimizer_selected] == 3:
-            run_sa(current_schedule, to_schedule, mas_full)
+            run_sa(current_schedule, to_schedule, mas_full, disc_selected)
         if optimizer_dict[optimizer_selected] == 4:
-            run_ga(current_schedule, to_schedule, mas_full)
+            run_ga(current_schedule, to_schedule, mas_full, disc_selected)
 
     b4 = Button(frame3, text='Generate Schedule', command=generate_schedule)
     b4.place(relx=0.37, rely=0.65)
@@ -252,7 +262,6 @@ def main_screen():
     Button(text='Login', height='1', width='10', command=login_button).place(relx=.5, rely=.5, anchor="center")
     Button(text='Register', height='1' ,width='10', command=register_page).place(relx=.5, rely=.55, anchor="center")
 
-
     screen.mainloop()
 
 
